summaryrefslogtreecommitdiff
path: root/netci.groovy
diff options
context:
space:
mode:
authorRuss Keldorph <russ.keldorph@microsoft.com>2019-01-31 15:20:41 -0800
committerRuss Keldorph <russ.keldorph@microsoft.com>2019-01-31 15:22:39 -0800
commit193d5da27fecb7bf95e7342f1c4b9e2b63ce5313 (patch)
tree31b2fe52164422d3e10e34eb884bcfc425b62799 /netci.groovy
parentd59e2b71b85c4b52eede67d41d31617dbd51bc90 (diff)
downloadcoreclr-193d5da27fecb7bf95e7342f1c4b9e2b63ce5313.tar.gz
coreclr-193d5da27fecb7bf95e7342f1c4b9e2b63ce5313.tar.bz2
coreclr-193d5da27fecb7bf95e7342f1c4b9e2b63ce5313.zip
Re-point Jenkins to new Ubuntu ARM64 queue
Move Jenkins off the Ubuntu.1604.Arm64.Open queue so it can be repurposed for Azure DevOps. This "Iron" queue should only be used by Jenkins.
Diffstat (limited to 'netci.groovy')
-rwxr-xr-xnetci.groovy4
1 files changed, 2 insertions, 2 deletions
diff --git a/netci.groovy b/netci.groovy
index b9d6951974..d68d0ae580 100755
--- a/netci.groovy
+++ b/netci.groovy
@@ -727,7 +727,7 @@ def static setMachineAffinity(def job, def os, def architecture, def options = n
//
// Arm64 (Build) -> arm64-cross-latest
// |-> os != "Windows_NT" && architecture == "arm64" && options['is_build_job'] == true
// Arm64 (Test) -> Helix Ubuntu.1604.Arm64.Open queue
// |-> os != "Windows_NT" && architecture == "arm64"
//
// Note: we are no longer using Jenkins tags "arm64-huge-page-size", "arm64-small-page-size".
@@ -772,7 +772,7 @@ def static setMachineAffinity(def job, def os, def architecture, def options = n
if (architecture == 'arm64') {
assert os == 'Ubuntu16.04'
job.with {
- label('Ubuntu.1604.Arm64.Open')
+ label('Ubuntu.1604.Arm64.Iron.Open')
}
}
else {
@@ -727,7 +727,7 @@ def static setMachineAffinity(def job, def os, def architecture, def options = n
// Arm64 (Build) -> arm64-cross-latest
// |-> os != "Windows_NT" && architecture == "arm64" && options['is_build_job'] == true
- // Arm64 (Test) -> Helix Ubuntu.1604.Arm64.Open queue
+ // Arm64 (Test) -> Helix Ubuntu.1604.Arm64.Iron.Open queue
// |-> os != "Windows_NT" && architecture == "arm64"
//